
#ifndef CYRF6936_H_
#define CYRF6936_H_

class CYRF6936
{
private:
    /*!
     * Number of the slave select (CS) pin.
     */
    unsigned char m_pinCS;

    /*!
     * Number of the clock (SCK) pin.
     */
    unsigned char m_pinSCK;

    /*!
     * Number of the master output, slave input (MOSI) pin.
     */
    unsigned char m_pinMOSI;

    /*!
     * Number of the master input, slave output (MISO) pin.
     */
    unsigned char m_pinMISO;

public:
    /*!
     * Constructor.
     *
     * \param[in] pinCS Pin number of slave select, default is 10.
     * \param[in] pinSCK Pin number of clock, default is 13 (Arduino standard).
     * \param[in] pinMOSI Pin number of master output slave input, default is 11 (Arduino standard).
     * \param[in] pinMISO Pin number of master input slave output, default is 12 (Arduino standard).
     */
    CYRF6936(unsigned char pinCS = 10,
           unsigned char pinSCK = 13,
           unsigned char pinMOSI = 11,
           unsigned char pinMISO = 12);

    /*!
     * Destructor.
     */
    ~CYRF6936();

    /*!
     * Initializes the CYRF6936 by setting the pin modes and disabling the device (slave select is
     * set to high). Also sets up the arduino SPI control register (SPCR).
     */
    void init();


    /*!
     * Sends a byte of data to the CYRF6936 using SPI. The received byte is returned.
     *
     * \param[in] data Byte of data to send.
     * \return Received byte.
     */
    unsigned char sendByte(unsigned char data);

    /*!
     * Sends a command and a byte of data to the CYRF6936 using SPI. Can be used to (1) write to a
     * configuration register, (2) read a configuration register (by writing dummy data), (3)
     * writing to patable memory if single access writes are used. Burst bit may be set, but burst
     * access is not allowed!
     *
     * See datasheet, chapters 10 & 32 for more information.
     *
     * \param[in] command Command to send, can be register/patable memory, can be write or read.
     * \param[in] data Data to send, can be dummy data when read command is issued.
     * \return Received byte.
     */
    unsigned char sendCommand(unsigned char command, unsigned char data);
	
	unsigned char sendCommand2(unsigned char command, unsigned char data, unsigned char data2);

    /*!
     * Sends a strobe command to the CYRF6936 using SPI. For a strobe command no data is necessary.
     *
     * See datasheet, chapter 32 for more information.
     *
     * \param[in] command Strobe command to send.
     * \return Received byte.
     */
    unsigned char sendStrobeCommand(unsigned char command);

    /*!
     * Sends a burst command to the CYRF6936 using SPI. The burst bit (0x40) in the command must be
     * set!
     *
     * \param[in] command Burst command to send.
     * \param[in] data Data bytes to send, will be filled with received bytes.
     * \param[in] length Number of data bytes to send.
     * \return Last received byte, also stored in data[length-1].
     */
    unsigned char sendBurstCommand(unsigned char command,
                                   unsigned char* data,
                                   unsigned char length);
								   
	
	unsigned char receiveBurstData(unsigned char command, unsigned char* data, unsigned char length);

protected:
    /*!
     * Transfers a byte of data using the Arduino SPI registers.
     *
     * \param[in] data Byte of data to send.
     * \return Received byte.
     */
    unsigned char spiTransfer(volatile unsigned char data);
};

#endif
